#!/bin/sh
BASEDIRS="../src ../data" # roots of translatable sources
PROJECT="katelatexplugin" # project name
BUGADDR="glad.deschrijver@gmail.com" # MSGID-Bugs
WDIR=`pwd` # working dir

add_list()
{
	LIST=$1

	if [ -z "$LIST" ]
	then
		echo ">>ERR<< add_list() - missing parameter LIST - exiting"
		return
	fi

	if [ -f "$LIST" ]
	then
		cat $LIST | while read ROW
		do
			echo "tr2i18n(\"${ROW}\")" >> ${WDIR}/rc.cpp
		done
	else
		echo ">>ERR<< add_list() - file $LIST does not exist."
	fi
}

echo "Preparing rc files"
# we use simple sorting to make sure the lines do not jump around too much from system to system
find ${BASEDIRS} -name '*.rc' -o -name '*.ui' -o -name '*.kcfg' | sort > ${WDIR}/rcfiles.list
xargs --arg-file=${WDIR}/rcfiles.list extractrc > ${WDIR}/rc.cpp
# additional string for KAboutData
echo 'i18nc("NAME OF TRANSLATORS","Your names");' >> ${WDIR}/rc.cpp
echo 'i18nc("EMAIL OF TRANSLATORS","Your emails");' >> ${WDIR}/rc.cpp
echo "Done preparing rc files"


echo "Extracting messages"
# see above on sorting
find ${BASEDIRS} -name '*.cpp' -o -name '*.h' -o -name '*.c' | sort > ${WDIR}/infiles.list
echo "rc.cpp" >> ${WDIR}/infiles.list
DBASEDIRS=`echo $BASEDIRS | sed -e "s/\([^\ ]*\)/-D \\1/g"`
xgettext --from-code=UTF-8 -C -kde -ci18n -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 -ki18ncp:1c,2,3 -ktr2i18n:1 \
	-kI18N_NOOP:1 -kI18N_NOOP2:1c,2 -kaliasLocale -kki18n:1 -kki18nc:1c,2 -kki18np:1,2 -kki18ncp:1c,2,3 \
	--msgid-bugs-address="${BUGADDR}" \
	--files-from=${WDIR}/infiles.list ${DBASEDIRS} -D ${WDIR} -o ${PROJECT}.pot || { echo "error while calling xgettext. aborting."; exit 1; }
echo "Done extracting messages"


echo "Merging translations"
catalogs=`find . -name '*.po'`
for cat in $catalogs; do
	echo $cat
	msgmerge -o $cat.new $cat ${PROJECT}.pot
	mv $cat.new $cat
done
echo "Done merging translations"


echo "Cleaning up"
rm ${WDIR}/rcfiles.list
rm ${WDIR}/infiles.list
rm ${WDIR}/rc.cpp
echo "Done"
